==> mx-packageinstaller-pkglist_18.12.06.tar.xz: mx-packageinstaller-pkglist/chromium.pm <==
<?xml version="1.0"?>
<app>

<category>
Browser
</category>

<name>
Chromium
</name>

<description>
   <am>Latest Chromium browser and language pack</am>
   <ca>Darrer navegador Chromium i paquets de llengua</ca>
   <cs>Latest Chromium browser and language pack</cs>
   <da>Latest Chromium browser and language pack</da>
   <de>Aktueller Chrombrowser und Sprachpaket</de>
   <el>Τελευταίο πρόγραμμα περιήγησης Chromium και το πακέτο γλωσσών</el>
   <en>Latest Chromium browser and language pack</en>
   <es>Latest Chromium browser and language pack</es>
   <fi>Latest Chromium browser and language pack</fi>
   <fr>La dernière version de Chromium et son pack de langues</fr>
   <hi>Latest Chromium browser and language pack</hi>
   <hr>Latest Chromium browser and language pack</hr>
   <hu>Latest Chromium browser and language pack</hu>
   <is>Latest Chromium browser and language pack</is>
   <it>Ultimo browser Chromium con pacchetto della lingua</it>
   <ja>Latest Chromium browser and language pack</ja>
   <kk>Latest Chromium browser and language pack</kk>
   <lt>Latest Chromium browser and language pack</lt>
   <nl>Meest recente Chromium browser en talen pakket</nl>
   <pl>Latest Chromium browser and language pack</pl>
   <pt_BR>Navegador Chromium mais recente e respectivo pacote de idiomas</pt_BR>
   <pt>Navegador Chromium mais recente e respectivo pacote de idiomas</pt>
   <ro>Latest Chromium browser and language pack</ro>
   <ru>Браузер Chromium последней версии и языковые пакеты</ru>
   <sk>Latest Chromium browser and language pack</sk>
   <sq>Latest Chromium browser and language pack</sq>
   <sv>Senaste Chromium webbläsare med språkpaket</sv>
   <tr>Latest Chromium browser and language pack</tr>
   <uk>Latest Chromium browser and language pack</uk>
   <zh_TW>Latest Chromium browser and language pack</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/269/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
chromium
chromium-l10n
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
chromium
chromium-l10n
</uninstall_package_names>
</app>

==> mx-packageinstaller-pkglist_19.01.03.tar.xz: mx-packageinstaller-pkglist/chromium.pm <==
<?xml version="1.0"?>
<app>

<category>
Browser
</category>

<name>
Chromium
</name>

<description>
   <am>Latest Chromium browser and language pack</am>
   <ar>Latest Chromium browser and language pack</ar>
   <bg>Latest Chromium browser and language pack</bg>
   <ca>Darrer navegador Chromium i paquets de llengua</ca>
   <cs>Latest Chromium browser and language pack</cs>
   <da>Seneste Chromium-browser og -sprogpakke</da>
   <de>Aktueller Chrombrowser und Sprachpaket</de>
   <el>Τελευταίο πρόγραμμα περιήγησης Chromium και το πακέτο γλωσσών</el>
   <en>Latest Chromium browser and language pack</en>
   <es>El último navegador Chromium con paquete de idioma</es>
   <et>Latest Chromium browser and language pack</et>
   <eu>Latest Chromium browser and language pack</eu>
   <fa>Latest Chromium browser and language pack</fa>
   <fi>Latest Chromium browser and language pack</fi>
   <fr>La dernière version de Chromium et son pack de langues</fr>
   <he_IL>Latest Chromium browser and language pack</he_IL>
   <hi>Latest Chromium browser and language pack</hi>
   <hr>Latest Chromium browser and language pack</hr>
   <hu>Latest Chromium browser and language pack</hu>
   <id>Latest Chromium browser and language pack</id>
   <is>Latest Chromium browser and language pack</is>
   <it>Ultimo browser Chromium con pacchetto della lingua</it>
   <ja_JP>Latest Chromium browser and language pack</ja_JP>
   <ja>Latest Chromium browser and language pack</ja>
   <kk>Latest Chromium browser and language pack</kk>
   <ko>Latest Chromium browser and language pack</ko>
   <lt>Latest Chromium browser and language pack</lt>
   <mk>Latest Chromium browser and language pack</mk>
   <nb>Latest Chromium browser and language pack</nb>
   <nl>Meest recente Chromium browser en talen pakket</nl>
   <pl>Latest Chromium browser and language pack</pl>
   <pt_BR>Navegador Chromium mais recente e respectivo pacote de idiomas</pt_BR>
   <pt>Navegador Chromium mais recente e respectivo pacote de idiomas</pt>
   <ro>Latest Chromium browser and language pack</ro>
   <ru>Браузер Chromium последней версии и языковые пакеты</ru>
   <sk>Latest Chromium browser and language pack</sk>
   <sl>Latest Chromium browser and language pack</sl>
   <sq>Latest Chromium browser and language pack</sq>
   <sr>Latest Chromium browser and language pack</sr>
   <sv>Senaste Chromium webbläsare med språkpaket</sv>
   <tr>Latest Chromium browser and language pack</tr>
   <uk>Крайня версія браузера Chromium з пакетом мов</uk>
   <zh_CN>Latest Chromium browser and language pack</zh_CN>
   <zh_TW>Latest Chromium browser and language pack</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/015/269/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
chromium
chromium-l10n
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
chromium
chromium-l10n
</uninstall_package_names>
</app>
